@@ -9,10 +9,10 @@ from optimade.models import (
     ErrorResponse,
     InfoResponse,
     EntryInfoResponse,
-    StructureResource,
 )
 from optimade.server.routers.utils import meta_values
 
+from aiida_optimade.models import StructureResource
 from aiida_optimade.utils import retrieve_queryable_properties
 
 
@@ -40,10 +40,10 @@ def get_info(request: Request):
             id=BaseInfoResource.schema()["properties"]["id"]["const"],
             type=BaseInfoResource.schema()["properties"]["type"]["const"],
             attributes=BaseInfoAttributes(
-                api_version=f"v{__api_version__}",
+                api_version=__api_version__,
                 available_api_versions=[
                     {
-                        "url": f"{base_url}/v{__api_version__.split('.')[0]}",
+                        "url": f"{base_url}/v{__api_version__.split('-')[0].split('+')[0].split('.')[0]}",
                         "version": __api_version__,
                     }
                 ],
@@ -51,6 +51,7 @@ def get_info(request: Request):
                 entry_types_by_format={"json": list(ENTRY_INFO_SCHEMAS.keys())},
                 available_endpoints=[
                     "info",
+                    "links",
                     "extensions/docs",
                     "extensions/redoc",
                     "extensions/openapi.json",
@@ -91,7 +92,7 @@ def get_info_entry(request: Request, entry: str):
             formats=list(output_fields_by_format.keys()),
             description=schema.get(
                 "description",
-                "Endpoint to represent AiiDA Nodes in the OPTiMaDe format",
+                "Endpoint to represent AiiDA Nodes in the OPTIMADE format",
             ),
             properties=properties,
             output_fields_by_format=output_fields_by_format,
